==> kubernetes-model-1.0.65-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DaemonSetStatusBuilder extends DaemonSetStatusFluentImpl<DaemonSetStatusBuilder> implements VisitableBuilder<DaemonSetStatus,DaemonSetStatusBuilder>{

    DaemonSetStatusFluent<?> fluent;
    Boolean validationEnabled;

    public DaemonSetStatusBuilder(){
            this(true);
    }
    public DaemonSetStatusBuilder(Boolean validationEnabled){
            this(new DaemonSetStatus(), validationEnabled);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent){
            this(fluent, true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DaemonSetStatus(), validationEnabled);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,DaemonSetStatus instance){
            this(fluent, instance, true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,DaemonSetStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCurrentNumberScheduled(instance.getCurrentNumberScheduled()); 
            fluent.withDesiredNumberScheduled(instance.getDesiredNumberScheduled()); 
            fluent.withNumberMisscheduled(instance.getNumberMisscheduled()); 
            this.validationEnabled = validationEnabled; 
    }
    public DaemonSetStatusBuilder(DaemonSetStatus instance){
            this(instance,true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCurrentNumberScheduled(instance.getCurrentNumberScheduled()); 
            this.withDesiredNumberScheduled(instance.getDesiredNumberScheduled()); 
            this.withNumberMisscheduled(instance.getNumberMisscheduled()); 
            this.validationEnabled = validationEnabled; 
    }

    public DaemonSetStatus build(){
            DaemonSetStatus buildable = new DaemonSetStatus(fluent.getCurrentNumberScheduled(),fluent.getDesiredNumberScheduled(),fluent.getNumberMisscheduled());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DaemonSetStatusBuilder that = (DaemonSetStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DaemonSetStatusBuilder extends DaemonSetStatusFluentImpl<DaemonSetStatusBuilder> implements VisitableBuilder<DaemonSetStatus,DaemonSetStatusBuilder>{

    DaemonSetStatusFluent<?> fluent;
    Boolean validationEnabled;

    public DaemonSetStatusBuilder(){
            this(true);
    }
    public DaemonSetStatusBuilder(Boolean validationEnabled){
            this(new DaemonSetStatus(), validationEnabled);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent){
            this(fluent, true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DaemonSetStatus(), validationEnabled);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,DaemonSetStatus instance){
            this(fluent, instance, true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatusFluent<?> fluent,DaemonSetStatus instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCurrentNumberScheduled(instance.getCurrentNumberScheduled()); 
            fluent.withDesiredNumberScheduled(instance.getDesiredNumberScheduled()); 
            fluent.withNumberMisscheduled(instance.getNumberMisscheduled()); 
            fluent.withNumberReady(instance.getNumberReady()); 
            this.validationEnabled = validationEnabled; 
    }
    public DaemonSetStatusBuilder(DaemonSetStatus instance){
            this(instance,true);
    }
    public DaemonSetStatusBuilder(DaemonSetStatus instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCurrentNumberScheduled(instance.getCurrentNumberScheduled()); 
            this.withDesiredNumberScheduled(instance.getDesiredNumberScheduled()); 
            this.withNumberMisscheduled(instance.getNumberMisscheduled()); 
            this.withNumberReady(instance.getNumberReady()); 
            this.validationEnabled = validationEnabled; 
    }

    public DaemonSetStatus build(){
            DaemonSetStatus buildable = new DaemonSetStatus(fluent.getCurrentNumberScheduled(),fluent.getDesiredNumberScheduled(),fluent.getNumberMisscheduled(),fluent.getNumberReady());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DaemonSetStatusBuilder that = (DaemonSetStatusBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
